Package: rnassqs
Type: Package
Title: Access Data from the NASS 'Quick Stats' API
Version: 0.6.3
Authors@R: c(
  person('Nicholas', 'Potter', email='econpotter@gmail.com', role = c('aut', 'cre')),
  person('Robert', 'Dinterman', email='', role = c('ctb')),
  person('Jonathan', 'Adams', email='', role = c('ctb')),
  person('Joseph', 'Stachelek', email='', role = c('ctb')),
  person('Julia', 'Piaskowski', email='', role = c('ctb')),
  person('Branden', 'Collingsworth', email='', role = c('ctb')),
  person('Adam', 'Sparks', email='', role = c('rev')),
  person('Neal', 'Richardson', email='', role = c('ctb', 'rev'))) 
Maintainer: Nicholas Potter <econpotter@gmail.com>
Description: Interface to access data via the United States Department of 
  Agriculture's National Agricultural Statistical Service (NASS) 'Quick Stats' 
  web API <https://quickstats.nass.usda.gov/api/>. Convenience functions 
  facilitate building queries based on available parameters and valid parameter 
  values. This product uses the NASS API but is not endorsed or certified by NASS.
URL: https://docs.ropensci.org/rnassqs/ (website)
        https://github.com/ropensci/rnassqs/
BugReports: https://github.com/ropensci/rnassqs/issues
License: MIT + file LICENSE
Language: en-US
Depends: R (>= 3.5.0)
Imports: httr, jsonlite, stats, utils
Suggests: here, httptest, knitr, rmarkdown, testthat
RoxygenNote: 7.3.2
Encoding: UTF-8
VignetteBuilder: knitr
Collate: 'auth.R' 'helpers.R' 'rnassqs-package.R' 'params.R'
        'request.R' 'wrappers.R'
NeedsCompilation: no
Packaged: 2024-08-29 23:24:09 UTC; potte
Author: Nicholas Potter [aut, cre],
  Robert Dinterman [ctb],
  Jonathan Adams [ctb],
  Joseph Stachelek [ctb],
  Julia Piaskowski [ctb],
  Branden Collingsworth [ctb],
  Adam Sparks [rev],
  Neal Richardson [ctb, rev]
Repository: CRAN
Date/Publication: 2024-08-30 03:50:02 UTC
Built: R 4.6.0; ; 2026-04-28 10:04:14 UTC; unix
